/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Initial Developer of the Original Code is
 *  William Liao <liao@pie.com.tw>.
 * Portions created by the Initial Developer are Copyright (C) 2004
 * the Initial Developer. All Rights Reserved.
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */
var m2kOptions = null;

function m2kOptionsLoad()
{
  m2kOptions = new m2kOptionsManager();
  m2kOptions.init();
}

function m2kOptionsUnload()
{
  m2kOptions.destroy();
  m2kOptions = null;
}

function m2kOptionsManager()
{
  return this;
}

m2kOptionsManager.prototype =
{
	gM2kOptParent: null,
	btnForget: null,
	
	init: function()
	{
		gM2kOptParent = window.opener.gM2kNotifier;
		btnForget = document.documentElement.getButton("help");
		this.fillForm();
	},
	
	destroy: function()
	{
		gM2kOptParent = null;
		btnForget = null;
	},
	
	fillForm: function()
	{
		btnForget.setAttribute("disabled", true);
		document.getElementById("m2k.prefs.customized-server").checked = gM2kOptParent.mBranch.getBoolPref("pref.customized-server");
		if (gM2kOptParent.mBranch.getBoolPref("pref.customized-server"))
		{
			//Close Menu
			document.getElementById("m2k.prefs.server-hbox").setAttribute ("collapsed", "true");
			document.getElementById("m2k.prefs.customized-loginserver-hbox").removeAttribute ("collapsed");
			document.getElementById("m2k.prefs.customized-loginserver").value = gM2kOptParent.mBranch.getCharPref("pref.server");
		}
		else
		{
			//Use Menu
			document.getElementById("m2k.prefs.customized-loginserver-hbox").setAttribute ("collapsed", "true");
			document.getElementById("m2k.prefs.server-hbox").removeAttribute ("collapsed");
			document.getElementById("m2k.prefs.server").selectedItem = document.getElementById(gM2kOptParent.mBranch.getCharPref("pref.server"));
		}

		document.getElementById("m2k.prefs.userid").value = gM2kOptParent.mBranch.getCharPref("pref.userid");
		document.getElementById("m2k.prefs.frequency").value = gM2kOptParent.mBranch.getIntPref("pref.freq");
		if (gM2kOptParent.mBranch.getBoolPref("pref.remember"))
		{
			document.getElementById("m2k.prefs.passwd").value = gM2kOptParent.PASSWD;
			document.getElementById("m2k.prefs.remember").checked = true;
			btnForget.removeAttribute("disabled");
		}
		else
		{
			document.getElementById("m2k.prefs.remember").checked = false;
		}
	},
	accept: function()
	{
		gM2kOptParent.mProfileIsLoaded = false;
		if (document.getElementById("m2k.prefs.customized-server").checked)
		{
			gM2kOptParent.mBranch.setCharPref("pref.server", document.getElementById("m2k.prefs.customized-loginserver").value);
		}
		else
		{
			gM2kOptParent.mBranch.setCharPref("pref.server", document.getElementById("m2k.prefs.server").value);
		}
		gM2kOptParent.mBranch.setCharPref("pref.userid", document.getElementById("m2k.prefs.userid").value);
		gM2kOptParent.mBranch.setBoolPref("pref.customized-server", document.getElementById("m2k.prefs.customized-server").checked);
		gM2kOptParent.PASSWD = document.getElementById("m2k.prefs.passwd").value;
		if(!isNaN(document.getElementById("m2k.prefs.frequency").value))
		{
			gM2kOptParent.mBranch.setIntPref("pref.freq", document.getElementById("m2k.prefs.frequency").value);
		}

		gM2kOptParent.mProfileIsLoaded = true;

		if (document.getElementById("m2k.prefs.remember").checked)
		{
			gM2kOptParent.mBranch.setBoolPref("pref.remember", true);
			gM2kOptParent.passManager ("add");
		}
		else
		{
			gM2kOptParent.mBranch.setBoolPref("pref.remember", false);
			gM2kOptParent.passManager ("remove");
		}

		gM2kOptParent.LOGGED_IN = true;
		gM2kOptParent.resetMsgStatus();
		gM2kOptParent.setupShortInterval(1000);
	},

	
	forgetPass: function()
	{
		btnForget.setAttribute("disabled", true);
		gM2kOptParent.mBranch.setBoolPref("pref.remember", false);
		document.getElementById("m2k.prefs.remember").checked = false;
		document.getElementById("m2k.prefs.passwd").value = "";
	},
		
	updateButtons: function (aEvent)
	{
		btnForget.removeAttribute("disabled");
	},
		
	chkCheckboxStatus: function ()
	{
		if (document.getElementById("m2k.prefs.remember").checked == false)
		{
			//Forget password
			gM2kOptParent.passManager("remove");
		}
	},
		
	chkCustomizedServer: function ()
	{
		if (document.getElementById("m2k.prefs.customized-server").checked == true)
		{
			//Close Menu
			document.getElementById("m2k.prefs.server-hbox").setAttribute ("collapsed", "true");
			document.getElementById("m2k.prefs.customized-loginserver-hbox").removeAttribute ("collapsed");
			document.getElementById("m2k.prefs.customized-loginserver").value = gM2kOptParent.mBranch.getCharPref("pref.server");
		}
		else
		{
			//Use Menu
			document.getElementById("m2k.prefs.customized-loginserver-hbox").setAttribute ("collapsed", "true");
			document.getElementById("m2k.prefs.server-hbox").removeAttribute ("collapsed");
			document.getElementById("m2k.prefs.server").selectedItem = document.getElementById(gM2kOptParent.mBranch.getCharPref("pref.server"));
		}
	},

};
